==> jc-1.4.0.tar.gz: soot/toolkits/graph/StronglyConnectedComponents.h <==
// public class soot.toolkits.graph.StronglyConnectedComponents

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bd9b2d273b9e5e46 soot_toolkits_graph_StronglyConnectedComponents

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_graph_StronglyConnectedComponents_H_
#define _JC_soot_toolkits_graph_StronglyConnectedComponents_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_List$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;
struct _jc_soot_toolkits_graph_MutableDirectedGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_StronglyConnectedComponents$sub_refs	_jc_soot_toolkits_graph_StronglyConnectedComponents$sub_refs;
typedef struct _jc_soot_toolkits_graph_StronglyConnectedComponents$sub_nonrefs	_jc_soot_toolkits_graph_StronglyConnectedComponents$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_StronglyConnectedComponents$refs	_jc_soot_toolkits_graph_StronglyConnectedComponents$refs;
typedef struct _jc_soot_toolkits_graph_StronglyConnectedComponents$nonrefs	_jc_soot_toolkits_graph_StronglyConnectedComponents$nonrefs;
typedef struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object	_jc_soot_toolkits_graph_StronglyConnectedComponents$object;

typedef struct _jc_soot_toolkits_graph_StronglyConnectedComponents$fields_struct	_jc_soot_toolkits_graph_StronglyConnectedComponents$fields_struct;
typedef const struct _jc_soot_toolkits_graph_StronglyConnectedComponents$vmethods	_jc_soot_toolkits_graph_StronglyConnectedComponents$vmethods;
typedef const struct _jc_soot_toolkits_graph_StronglyConnectedComponents$vtable	_jc_soot_toolkits_graph_StronglyConnectedComponents$vtable;
typedef const struct _jc_soot_toolkits_graph_StronglyConnectedComponents$vtype	_jc_soot_toolkits_graph_StronglyConnectedComponents$vtype;

// Class fields structure
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$fields_struct {
	struct _jc_java_lang_Object$object	*Black;
	struct _jc_java_lang_Object$object	*Visited;
};
extern _jc_soot_toolkits_graph_StronglyConnectedComponents$fields_struct _jc_soot_toolkits_graph_StronglyConnectedComponents$class_fields;

// Constructors
extern void _jc_soot_toolkits_graph_StronglyConnectedComponents$method$_init$ac2601640312c3c2(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_toolkits_graph_StronglyConnectedComponents$method$equivalent$b54c6f8e9be2d1cd(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_soot_toolkits_graph_StronglyConnectedComponents$method$getComponentOf$1825c9be4e75132e(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_soot_toolkits_graph_StronglyConnectedComponents$method$getComponents$d552904f0062793c(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *);
extern struct _jc_object *_jc_soot_toolkits_graph_StronglyConnectedComponents$method$getSuperGraph$5fe5d5f6a544877f(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *);
extern void _jc_soot_toolkits_graph_StronglyConnectedComponents$method$visitNode$00047c36f8f1b0cd(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_object *, struct _jc_java_lang_Object$object *);
extern void _jc_soot_toolkits_graph_StronglyConnectedComponents$method$visitRevNode$51535829904f98fe(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_graph_StronglyConnectedComponents$method_info$equivalent$b54c6f8e9be2d1cd;
extern _jc_method _jc_soot_toolkits_graph_StronglyConnectedComponents$method_info$getComponentOf$1825c9be4e75132e;
extern _jc_method _jc_soot_toolkits_graph_StronglyConnectedComponents$method_info$getComponents$d552904f0062793c;
extern _jc_method _jc_soot_toolkits_graph_StronglyConnectedComponents$method_info$getSuperGraph$5fe5d5f6a544877f;
extern _jc_method _jc_soot_toolkits_graph_StronglyConnectedComponents$method_info$visitNode$00047c36f8f1b0cd;
extern _jc_method _jc_soot_toolkits_graph_StronglyConnectedComponents$method_info$visitRevNode$51535829904f98fe;

// Static methods
extern void _jc_soot_toolkits_graph_StronglyConnectedComponents$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$vmethods {
	jboolean	(*equivalent$b54c6f8e9be2d1cd)(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*getComponentOf$1825c9be4e75132e)(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*getComponents$d552904f0062793c)(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *);
	struct _jc_object	*(*getSuperGraph$5fe5d5f6a544877f)(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *);
	void	(*visitNode$00047c36f8f1b0cd)(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_object *, struct _jc_java_lang_Object$object *);
	void	(*visitRevNode$51535829904f98fe)(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_StronglyConnectedComponents$vmethods	soot_toolkits_graph_StronglyConnectedComponents;
};

// Vtype
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_StronglyConnectedComponents$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$sub_refs {
	struct _jc_java_util_HashMap$object	*nodeToColor;
	struct _jc_java_util_LinkedList$object	*finishingOrder;
	struct _jc_object	*componentList;
	struct _jc_java_util_HashMap$object	*nodeToComponent;
	struct _jc_object	*sccGraph;
	_jc_int_array	*indexStack;
	_jc_object_array	*nodeStack;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$refs {
    _jc_soot_toolkits_graph_StronglyConnectedComponents$sub_refs	soot_toolkits_graph_StronglyConnectedComponents;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$sub_nonrefs {
	jint	last;
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_StronglyConnectedComponents$sub_nonrefs	soot_toolkits_graph_StronglyConnectedComponents;
};

// Object instance structure
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object {
	_jc_soot_toolkits_graph_StronglyConnectedComponents$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_StronglyConnectedComponents$vtype	*vtype;
	_jc_soot_toolkits_graph_StronglyConnectedComponents$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_StronglyConnectedComponents$vtype _jc_soot_toolkits_graph_StronglyConnectedComponents$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_StronglyConnectedComponents, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_StronglyConnectedComponents$class_object;

#endif	/* _JC_soot_toolkits_graph_StronglyConnectedComponents_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/graph/StronglyConnectedComponents.h <==
// public class soot.toolkits.graph.StronglyConnectedComponents

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bd9b2d273b9e5e46 soot_toolkits_graph_StronglyConnectedComponents

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_graph_StronglyConnectedComponents_H_
#define _JC_soot_toolkits_graph_StronglyConnectedComponents_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_List$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;
struct _jc_soot_toolkits_graph_MutableDirectedGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_StronglyConnectedComponents$sub_refs	_jc_soot_toolkits_graph_StronglyConnectedComponents$sub_refs;
typedef struct _jc_soot_toolkits_graph_StronglyConnectedComponents$sub_nonrefs	_jc_soot_toolkits_graph_StronglyConnectedComponents$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_StronglyConnectedComponents$refs	_jc_soot_toolkits_graph_StronglyConnectedComponents$refs;
typedef struct _jc_soot_toolkits_graph_StronglyConnectedComponents$nonrefs	_jc_soot_toolkits_graph_StronglyConnectedComponents$nonrefs;
typedef struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object	_jc_soot_toolkits_graph_StronglyConnectedComponents$object;

typedef struct _jc_soot_toolkits_graph_StronglyConnectedComponents$fields_struct	_jc_soot_toolkits_graph_StronglyConnectedComponents$fields_struct;
typedef const struct _jc_soot_toolkits_graph_StronglyConnectedComponents$vmethods	_jc_soot_toolkits_graph_StronglyConnectedComponents$vmethods;
typedef const struct _jc_soot_toolkits_graph_StronglyConnectedComponents$vtable	_jc_soot_toolkits_graph_StronglyConnectedComponents$vtable;
typedef const struct _jc_soot_toolkits_graph_StronglyConnectedComponents$vtype	_jc_soot_toolkits_graph_StronglyConnectedComponents$vtype;

// Class fields structure
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$fields_struct {
	struct _jc_java_lang_Object$object	*Black;
	struct _jc_java_lang_Object$object	*Visited;
};
extern _jc_soot_toolkits_graph_StronglyConnectedComponents$fields_struct _jc_soot_toolkits_graph_StronglyConnectedComponents$class_fields;

// Constructors
extern void _jc_soot_toolkits_graph_StronglyConnectedComponents$method$_init$ac2601640312c3c2(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_toolkits_graph_StronglyConnectedComponents$method$equivalent$b54c6f8e9be2d1cd(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_toolkits_graph_StronglyConnectedComponents$method$getComponentOf$1825c9be4e75132e(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_toolkits_graph_StronglyConnectedComponents$method$getComponents$d552904f0062793c(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_toolkits_graph_StronglyConnectedComponents$method$getSuperGraph$5fe5d5f6a544877f(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_graph_StronglyConnectedComponents$method$visitNode$00047c36f8f1b0cd(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_graph_StronglyConnectedComponents$method$visitRevNode$51535829904f98fe(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_graph_StronglyConnectedComponents$method_info$equivalent$b54c6f8e9be2d1cd;
extern _jc_method _jc_soot_toolkits_graph_StronglyConnectedComponents$method_info$getComponentOf$1825c9be4e75132e;
extern _jc_method _jc_soot_toolkits_graph_StronglyConnectedComponents$method_info$getComponents$d552904f0062793c;
extern _jc_method _jc_soot_toolkits_graph_StronglyConnectedComponents$method_info$getSuperGraph$5fe5d5f6a544877f;
extern _jc_method _jc_soot_toolkits_graph_StronglyConnectedComponents$method_info$visitNode$00047c36f8f1b0cd;
extern _jc_method _jc_soot_toolkits_graph_StronglyConnectedComponents$method_info$visitRevNode$51535829904f98fe;

// Static methods
extern void _jc_soot_toolkits_graph_StronglyConnectedComponents$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$vmethods {
	jboolean	(*equivalent$b54c6f8e9be2d1cd)(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getComponentOf$1825c9be4e75132e)(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getComponents$d552904f0062793c)(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSuperGraph$5fe5d5f6a544877f)(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *) _JC_JCNI_ATTR;
	void	(*visitNode$00047c36f8f1b0cd)(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*visitRevNode$51535829904f98fe)(_jc_env *, struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_StronglyConnectedComponents$vmethods	soot_toolkits_graph_StronglyConnectedComponents;
};

// Vtype
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_StronglyConnectedComponents$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$sub_refs {
	struct _jc_java_util_HashMap$object	*nodeToColor;
	struct _jc_java_util_LinkedList$object	*finishingOrder;
	struct _jc_object	*componentList;
	struct _jc_java_util_HashMap$object	*nodeToComponent;
	struct _jc_object	*sccGraph;
	_jc_int_array	*indexStack;
	_jc_object_array	*nodeStack;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$refs {
    _jc_soot_toolkits_graph_StronglyConnectedComponents$sub_refs	soot_toolkits_graph_StronglyConnectedComponents;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$sub_nonrefs {
	jint	last;
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_StronglyConnectedComponents$sub_nonrefs	soot_toolkits_graph_StronglyConnectedComponents;
};

// Object instance structure
struct _jc_soot_toolkits_graph_StronglyConnectedComponents$object {
	_jc_soot_toolkits_graph_StronglyConnectedComponents$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_StronglyConnectedComponents$vtype	*vtype;
	_jc_soot_toolkits_graph_StronglyConnectedComponents$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_StronglyConnectedComponents$vtype _jc_soot_toolkits_graph_StronglyConnectedComponents$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_StronglyConnectedComponents, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_StronglyConnectedComponents$class_object;

#endif	/* _JC_soot_toolkits_graph_StronglyConnectedComponents_H_ */
